@@ -378,7 +378,7 @@ from ae.console import ConsoleApp                   # type: ignore
 from ae.files import FilesRegister, RegisteredFile  # type: ignore
 
 
-__version__ = '0.0.16'
+__version__ = '0.0.18'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -601,6 +601,30 @@ class MainAppBase(ConsoleApp, ABC):
 
         self.setup_app_states(app_state)
 
+    def on_font_size_change(self, _flow_id: str, event_kwargs: Dict[str, Any]) -> bool:
+        """ font size app state change event handler.
+
+        :param _flow_id:        flow id.
+        :param event_kwargs:    event kwargs with key `'font_size'` containing the new font size in pixels as float.
+        :return:                True for to confirm change of flow id.
+        """
+        font_size: float = event_kwargs['font_size']
+        self.dpo(f"MainAppBase.on_font_size_change {font_size}")
+        self.change_app_state('font_size', font_size)
+        return True
+
+    def on_light_theme_change(self, _flow_id: str, event_kwargs: Dict[str, Any]) -> bool:
+        """ font size app state change event handler.
+
+        :param _flow_id:        flow id.
+        :param event_kwargs:    event kwargs with key `'light_theme'` containing True|False for light|dark theme.
+        :return:                True for to confirm change of flow id.
+        """
+        light_theme: bool = event_kwargs['light_theme']
+        self.dpo(f"MainAppBase.on_light_theme_change to {light_theme}")
+        self.change_app_state('light_theme', light_theme)
+        return True
+
     def retrieve_app_states(self) -> AppStateType:
         """ determine the state of a running app from the config files and return it as dict.
 
@@ -704,6 +728,7 @@ class MainAppBase(ConsoleApp, ABC):
         if not self.call_method(flow_event_name(ifi), ifi, event_kwargs) \
                 and not self.on_flow_change(ifi, event_kwargs) \
                 and action not in ACTIONS_CHANGING_FLOW_WITHOUT_CONFIRMATION:
+            self.dpo(f"MainAppBase.change_flow REJECTED '{ifi}'; flow='{self.flow_id}' path={self.flow_path}")
             return False
 
         if action in ACTIONS_EXTENDING_FLOW_PATH:
@@ -728,7 +753,7 @@ class MainAppBase(ConsoleApp, ABC):
         if flow_action(flow_id) == 'focus':
             self.call_method('on_flow_widget_focused')
 
-        self.dpo(f"MainAppBase.change_flow changed flow='{self.flow_id}' path={self.flow_path}")
+        self.dpo(f"MainAppBase.change_flow CHANGED {ifi}; flow='{self.flow_id}' path={self.flow_path}")
         return True
 
     def flow_path_action(self, path_index: int = -1) -> str:
@@ -754,7 +779,7 @@ class MainAppBase(ConsoleApp, ABC):
             popup_class = self.class_by_name(class_name)
             if popup_class:
                 popup_kwargs = event_kwargs.get('popup_kwargs', dict())
-                self.show_popup(popup_class(**popup_kwargs))
+                self.show_popup(popup_class, **popup_kwargs)
                 return True
         return False
 
@@ -833,29 +858,12 @@ class MainAppBase(ConsoleApp, ABC):
 
     def on_app_run(self):
         """ event fired after framework event loop got started. """
-        self.dpo(f"MainAppBase.on_app_run")
+        self.dpo("MainAppBase.on_app_run")
         self.change_flow(self.flow_id)
 
     def on_app_stop(self):
         """ event fired after framework win got closed and just before the event loop will be stopped. """
-        self.dpo(f"MainAppBase.on_app_stop")
-
-    def on_font_size_changed(self, font_size: float):
-        """ font size drop down clicked event handler.
-
-        :param font_size:   font size in pixels as float.
-        """
-        self.dpo(f"MainAppBase.on_font_size_changed {font_size}")
-        self.change_app_state('font_size', font_size)
-
-    def on_user_preference_theme_changed(self, theme: str):
-        """ user preference theme changed to either 'dark' or 'light'.
-
-        :param theme:   new theme, either 'light' or 'dark'.
-        """
-        self.dpo(f"MainAppBase.on_user_preference_theme_changed to '{theme}'")
-        to_light = theme == 'light'
-        self.change_app_state('light_theme', to_light)
+        self.dpo("MainAppBase.on_app_stop")
 
     def play_beep(self):
         """ make a short beep sound, should be overwritten by GUI framework. """
@@ -877,7 +885,7 @@ class MainAppBase(ConsoleApp, ABC):
 
     def run_app(self):
         """ startup main and framework applications. """
-        self.dpo(f"MainAppBase.run_app")
+        self.dpo("MainAppBase.run_app")
 
         if not self._parsed_args:
             self._parse_args()
@@ -888,16 +896,20 @@ class MainAppBase(ConsoleApp, ABC):
             finally:
                 self.shutdown(self._exit_code or None)  # don't call sys.exit() for zero exit code
 
-    def show_popup(self, popup: Any):
+    def show_popup(self, popup_class: Type, **popup_kwargs) -> Any:
         """ open Popup by calling `show` method of passed instance.
 
         Overwrite this method if framework is using different method to open Popup window or if
         a widget in the Popup need to get the input focus.
 
-        :param popup:   instance of the Popup widget/window.
+        :param popup_class:     class of the Popup widget/window.
+        :param popup_kwargs:    args for to instantiate and show/open the popup.
+        :return:                created and displayed/opened popup class instance.
         """
-        self.dpo(f"MainAppBase.show_popup {popup}")
-        popup.show()
+        self.dpo(f"MainAppBase.show_popup {popup_class} {popup_kwargs}")
+        popup_instance = popup_class(**popup_kwargs)
+        popup_instance.show()
+        return popup_instance
 
     def stop_app(self, exit_code: int = 0):
         """ quit this application.
@@ -929,12 +941,12 @@ class MainAppBase(ConsoleApp, ABC):
 
         return child_wid(self.framework_win.children)
 
-    def win_pos_size_changed(self, *win_pos_size):
+    def win_pos_size_change(self, *win_pos_size):
         """ screen resize handler (called on window resize or when app will exit/stop via closed event.
 
         :param win_pos_size:    window geometry/coordinates: x, y, width, height.
         """
         self.framework_app.landscape = win_pos_size[2] >= win_pos_size[3]
-        self.dpo(f"MainAppBase.win_pos_size_changed landscape={self.framework_app.landscape}, {win_pos_size}")
+        self.dpo(f"MainAppBase.win_pos_size_change landscape={self.framework_app.landscape}, {win_pos_size}")
         self.change_app_state('win_rectangle', win_pos_size)
         self.call_method('on_win_pos_size')
